#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-5a9cVUvDUjnDioPVLt8EQh
key:                  lsp-2.2.0.0-5a9cVUvDUjnDioPVLt8EQh
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  c3ff310412a7e58e10ca65b4fc8127ce
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-7XXm9pmxYcx9GzLTLYVS7e:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-7XXm9pmxYcx9GzLTLYVS7e:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-7XXm9pmxYcx9GzLTLYVS7e:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-7XXm9pmxYcx9GzLTLYVS7e:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-5a9cVUvDUjnDioPVLt8EQh
depends:
    aeson-2.2.1.0-HnfSu9AKfZzFhPBHWndcTt
    async-2.2.5-B3LTRS5ADZ11aNLUYaUoKB
    attoparsec-0.14.4-FWHL4j3hm4w7OAb6a2dq6Z base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-ZPEyu17VpcLUr0Hf8ddQ8
    containers-0.6.7 data-default-0.7.1.3-Jbl1GQbSIet3IvhyjwA92u
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-IX17aYqP3drGri7tV4VHWj
    lens-5.3.4-JjT83SfukR7AuYtg8v5LHK
    lens-aeson-1.2.3-EfTl9CPiDny7QnBvOQygf4
    lsp-types-2.0.2.0-7XXm9pmxYcx9GzLTLYVS7e mtl-2.3.1
    prettyprinter-1.7.1-5fp5g306PJQFs6XChHaX6T
    random-1.2.1.3-61dnBQTdVAfCNopGABDCH1
    row-types-1.0.1.2-3X77HHvGpbjD1ignZ062xN
    sorted-list-0.2.3.1-1SwfapLxgJoJTKUpu6w5Ny stm-2.5.1.0
    temporary-1.3-9cShmFmusTlHFNDsoL1bI8 text-2.0.2
    text-rope-0.3-17d4cvn6x9y1mlGIUKhwXG transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-50KuqheKibtHrVzrLcPiuM
    uuid-1.3.16-BxsDsyUzPb34doh5lAthbA

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

